{
	"name" : "Complete timesheet from an iCal server",
	"version" : "0.1",
	"author" : "Tiny",
	"category" : "Generic Modules/Human Resources",
	"website" : "http://tinyerp.com/module_hr.html",
	"description": "Import iCal events (for eg, Outlook) to auto-complete timesheets.",
	"depends" : ["hr_timesheet"],
	"init_xml" : [],
	"demo_xml" : [],
	"update_xml" : ["hr_timesheet_wizard.xml"],
	"active": False,
	"installable": True
}
